Character. Name of the class the method is defined.
This is important for super() to resolve the correct parent class.
Details
Multiple classes or instances can be provided in ..., where the right one
will override the left one if they have the same attribute or method name.
Attributes or methods that don't want to be copied can be specified in
avoid.