powered by
This function loads functions from package namespaces and assigns them to the preferred function names in the current environment.
define_pkg_fn(pkg, ...)
No return value, called for side effects.
Package.
Functions. Preferred names can be provide via named arguments.
Preferred function names can be provide via named arguments like info = cli_alert_info.
info = cli_alert_info
define_pkg_fn(pkg = cli, cli_alert_info, cli_alert_warning) define_pkg_fn(cli, cli_alert_warning, info = cli_alert_info)
Run the code above in your browser using DataLab