Learn R Programming

bandicoot (version 1.0.0)

is_bandicoot_oop: Check whether the object is a bandicoot_oop object

Description

This function check whether the object is a bandicoot_oop object.

Usage

is_bandicoot_oop(obj, why = FALSE)

Value

A Boolean value.

Arguments

obj

Any object.

why

Boolean. Whether or not to print the reason when the check fail.

Examples

Run this code

e <- new.env()
is_bandicoot_oop(e)

e <- new_class(class_name = "test")
is_bandicoot_oop(e)

Run the code above in your browser using DataLab