Learn R Programming

bandicoot (version 1.0.0)

len.bandicoot_oop: S3 method of computing the length of bandicoot_oop object

Description

This function computes the length of the object by using the ..len..() method. If it is not applicable, error will be raised.

Usage

# S3 method for bandicoot_oop
len(x, ...)

Value

An integer.

Arguments

x

bandicoot_oop object.

...

ignored.

Examples

Run this code
EMAIL <- new_class(class_name = "EMAIL")
email <- EMAIL$instantiate
register_method(EMAIL, ..init.. = function(address) self$address = address)
register_method(EMAIL, ..len.. = function() nchar(self$address))

patrick <- email('patrick@test.com')
len(patrick)

Run the code above in your browser using DataLab