powered by
bandicoot_oop
This function check whether the object is a bandicoot_oop object.
is_bandicoot_oop(obj, why = FALSE)
A Boolean value.
Any object.
Boolean. Whether or not to print the reason when the check fail.
e <- new.env() is_bandicoot_oop(e) e <- new_class(class_name = "test") is_bandicoot_oop(e)
Run the code above in your browser using DataLab